@@ -1,12 +1,18 @@
-from firstimpression.api import bbc
-from firstimpression.api import ns
-from firstimpression.api import nu_nl
-from firstimpression.api import traffic
-from firstimpression.api import request
-from firstimpression.api import insta
-from firstimpression.api import weather
 from firstimpression.api import amber_alert
 from firstimpression.api import ams_airport
+from firstimpression.api import bbc
+from firstimpression.api import chuck_norris
+from firstimpression.api import ehv_airport
 from firstimpression.api import facebook
+from firstimpression.api import google_trends
+from firstimpression.api import insta
 from firstimpression.api import interia
-from firstimpression.api import ehv_airport
\ No newline at end of file
+from firstimpression.api import ns
+from firstimpression.api import nu_nl
+from firstimpression.api import songkick
+from firstimpression.api import traffic
+from firstimpression.api import weather
+from firstimpression.api import request
+from firstimpression.api import solaredge
+from firstimpression.api import countdown
+from firstimpression.api import twitter
