@@ -108,6 +108,8 @@ def check_api():
     svars = variables()
     skip = False
 
+    file_exists = [True, True]
+
     file_path_longest = glob.glob(XML_LOCAL_LONGEST)
     file_path_closest = glob.glob(XML_LOCAL_CLOSEST)
 
@@ -125,6 +127,8 @@ def check_api():
     else:
         warn.log('File {} in {} does not exists'.format(XML_LOCAL_LONGEST, file_path_longest))
 
+        file_exists[0] = False
+
     if len(file_path_closest) > 0:
         file_path_closest = file_path_closest[0]
         debug.log('glob filepath: {}'.format(file_path_closest))
@@ -138,7 +142,13 @@ def check_api():
                 info.log('no traffic jams at the moment')
     else:
         warn.log('File {} in {} does not exists'.format(XML_LOCAL_CLOSEST, file_path_closest))
-            
+
+        file_exists[1] = False
+    
+    if skip == False:
+        if not any(file_exists):
+            skip = True
+
     svars['skipscript'] = skip
 
 ##################################################################################################
