@@ -117,7 +117,7 @@ def run_api(api_key, icon_set, location='', units='metric', lang='nl', coordinat
         params['lon'] = coordinates['longitude']
         params['lat'] = coordinates['latitude']
 
-    url_icons = 'http://37.97.211.104/narrowcasting/weather/weather_{}'.format(icon_set)
+    url_icons = 'https://fi-api.io/weather_images/{}'.format(icon_set)
 
     extensions = IMG_EXTENSIONS + VIDEO_EXTENSIONS
     
@@ -205,12 +205,13 @@ def check_api():
 ##################################################################################################
 
 def download_icons(url_icons, extensions, temp_folder_icons, icon_set):
-    icons = list_files(url_icons, extensions)
+    links = list_files(url_icons, extensions)
 
-    for icon in icons:
-        debug.log('icon: {}'.format(icon))
-        if check_too_old(os.path.join(temp_folder_icons, icon), MAX_FILE_AGE_IMAGES):
-            download_install_media(url_icons + '/{}'.format(icon), TEMP_FOLDER, '{}\\icons\\{}'.format(NAME, icon_set))
+    for link in links:
+        debug.log('icon link: {}'.format(link))
+        file_name = link.split('/')[-1]
+        if check_too_old(os.path.join(temp_folder_icons, file_name), MAX_FILE_AGE_IMAGES):
+            download_install_media(link, TEMP_FOLDER, '{}\\icons\\{}'.format(NAME, icon_set))
 
 
 ##################################################################################################
