@@ -11,8 +11,7 @@ PICTURE_FORMATS = {
 }
 
 TEMP_FOLDER = gettempdir()
-LOCAL_INTEGRATED_FOLDER = 'C:/Users/Public/Documents/Scala/LocalIntegratedContent'
-PLACEHOLDER_FOLDER = os.path.join(LOCAL_INTEGRATED_FOLDER, 'placeholders')
+LOCAL_INTEGRATED_FOLDER_LIST = ['C:/Users/Public/Documents/Scala/LocalIntegratedContent', 'D:/SCALA/PLAYER_CFG_DATA/Documents/LocalIntegratedContent']
 
 APIS = {
     'amber':'AMBER_ALERT',
@@ -79,4 +78,16 @@ NAMELEVEL = {
 
 SAMSUNG_MONITOR_ON_MESSAGE = b'\xAA\x11\xFE\x01\x01\x11'
 SAMSUNG_MONITOR_OFF_MESSAGE = b'\xAA\x11\xFE\x01\x00\x10'
-SAMSUNG_MONITOR_SWITCH_PORT = 1515
\ No newline at end of file
+SAMSUNG_MONITOR_SWITCH_PORT = 1515
+
+
+from firstimpression.scala import variables
+
+svars = variables()
+
+if svars['Player.local_integrated_folder_on_d']:
+    LOCAL_INTEGRATED_FOLDER = LOCAL_INTEGRATED_FOLDER_LIST[1]
+else:
+    LOCAL_INTEGRATED_FOLDER = LOCAL_INTEGRATED_FOLDER_LIST[0]
+
+PLACEHOLDER_FOLDER = os.path.join(LOCAL_INTEGRATED_FOLDER, 'placeholders')
\ No newline at end of file
